<?php

namespace Ionut\Biblio\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Ionut\Biblio\Http\Requests\EdituriRequest;
use Ionut\Biblio\Models\Edituri;

/**
 * Admin web controller class.
 */
class EdituriWorkflowController extends BaseController
{

    /**
     * Workflow controller function for edituri.
     *
     * @param Model   $edituri
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(EdituriRequest $request, Edituri $edituri, $step)
    {

        try {

            $edituri->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('biblio::edituri.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/edituri/edituri/' . $edituri->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/edituri/edituri/' . $edituri->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for edituri.
     *
     * @param Model   $edituri
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Edituri $edituri, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $edituri->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('biblio::edituri.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('biblio::admin.edituri.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('biblio::admin.edituri.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('biblio::admin.edituri.message', $data)->render();

        }

    }
}
