<?php

namespace Ionut\Biblio\Policies;

use Litepie\User\Contracts\UserPolicy;
use Ionut\Biblio\Models\Agenda;

class AgendaPolicy
{

    /**
     * Determine if the given user can view the agenda.
     *
     * @param UserPolicy $user
     * @param Agenda $agenda
     *
     * @return bool
     */
    public function view(UserPolicy $user, Agenda $agenda)
    {
        if ($user->canDo('biblio.agenda.view') && $user->isAdmin()) {
            return true;
        }

        return $agenda->user_id == user_id() && $agenda->user_type == user_type();
    }

    /**
     * Determine if the given user can create a agenda.
     *
     * @param UserPolicy $user
     * @param Agenda $agenda
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('biblio.agenda.create');
    }

    /**
     * Determine if the given user can update the given agenda.
     *
     * @param UserPolicy $user
     * @param Agenda $agenda
     *
     * @return bool
     */
    public function update(UserPolicy $user, Agenda $agenda)
    {
        if ($user->canDo('biblio.agenda.edit') && $user->isAdmin()) {
            return true;
        }

        return $agenda->user_id == user_id() && $agenda->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given agenda.
     *
     * @param UserPolicy $user
     * @param Agenda $agenda
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Agenda $agenda)
    {
        return $agenda->user_id == user_id() && $agenda->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given agenda.
     *
     * @param UserPolicy $user
     * @param Agenda $agenda
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Agenda $agenda)
    {
        if ($user->canDo('biblio.agenda.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given agenda.
     *
     * @param UserPolicy $user
     * @param Agenda $agenda
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Agenda $agenda)
    {
        if ($user->canDo('biblio.agenda.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
