<?php

namespace Ionut\Biblio\Policies;

use Litepie\User\Contracts\UserPolicy;
use Ionut\Biblio\Models\Edituri;

class EdituriPolicy
{

    /**
     * Determine if the given user can view the edituri.
     *
     * @param UserPolicy $user
     * @param Edituri $edituri
     *
     * @return bool
     */
    public function view(UserPolicy $user, Edituri $edituri)
    {
        if ($user->canDo('biblio.edituri.view') && $user->isAdmin()) {
            return true;
        }

        return $edituri->user_id == user_id() && $edituri->user_type == user_type();
    }

    /**
     * Determine if the given user can create a edituri.
     *
     * @param UserPolicy $user
     * @param Edituri $edituri
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('biblio.edituri.create');
    }

    /**
     * Determine if the given user can update the given edituri.
     *
     * @param UserPolicy $user
     * @param Edituri $edituri
     *
     * @return bool
     */
    public function update(UserPolicy $user, Edituri $edituri)
    {
        if ($user->canDo('biblio.edituri.edit') && $user->isAdmin()) {
            return true;
        }

        return $edituri->user_id == user_id() && $edituri->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given edituri.
     *
     * @param UserPolicy $user
     * @param Edituri $edituri
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Edituri $edituri)
    {
        return $edituri->user_id == user_id() && $edituri->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given edituri.
     *
     * @param UserPolicy $user
     * @param Edituri $edituri
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Edituri $edituri)
    {
        if ($user->canDo('biblio.edituri.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given edituri.
     *
     * @param UserPolicy $user
     * @param Edituri $edituri
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Edituri $edituri)
    {
        if ($user->canDo('biblio.edituri.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
