<?php

namespace Ionut\Biblio\Providers;

use Illuminate\Support\ServiceProvider;

class BiblioServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'biblio');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'biblio');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('ionut.biblio', function ($app) {
            return $this->app->make('Ionut\Biblio\Biblio');
        });

        // Bind Edituri to repository
        $this->app->bind(
            'Ionut\Biblio\Interfaces\EdituriRepositoryInterface',
            \Ionut\Biblio\Repositories\Eloquent\EdituriRepository::class
        );
        // Bind Agenda to repository
        $this->app->bind(
            'Ionut\Biblio\Interfaces\AgendaRepositoryInterface',
            \Ionut\Biblio\Repositories\Eloquent\AgendaRepository::class
        );

        $this->app->register(\Ionut\Biblio\Providers\AuthServiceProvider::class);
                $this->app->register(\Ionut\Biblio\Providers\EventServiceProvider::class);
        
        $this->app->register(\Ionut\Biblio\Providers\RouteServiceProvider::class);
                $this->app->register(\Ionut\Biblio\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['ionut.biblio'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('ionut/biblio.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/biblio')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/biblio')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
