<?php

namespace Ionut\Biblio\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Ionut\Biblio\Models\Agenda;

class AgendaAction
{
    /**
     * Perform the complete action.
     *
     * @param Agenda $agenda
     *
     * @return Agenda
     */
    public function complete(Agenda $agenda)
    {
        try {
            $agenda->status = 'complete';
            return $agenda->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Agenda $agenda
     *
     * @return Agenda
     */public function verify(Agenda $agenda)
    {
        try {
            $agenda->status = 'verify';
            return $agenda->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Agenda $agenda
     *
     * @return Agenda
     */public function approve(Agenda $agenda)
    {
        try {
            $agenda->status = 'approve';
            return $agenda->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Agenda $agenda
     *
     * @return Agenda
     */public function publish(Agenda $agenda)
    {
        try {
            $agenda->status = 'publish';
            return $agenda->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Agenda $agenda
     *
     * @return Agenda
     */
    public function archive(Agenda $agenda)
    {
        try {
            $agenda->status = 'archive';
            return $agenda->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Agenda $agenda
     *
     * @return Agenda
     */
    public function unpublish(Agenda $agenda)
    {
        try {
            $agenda->status = 'unpublish';
            return $agenda->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
