<?php

namespace Ionut\Biblio\Workflow;

use Ionut\Biblio\Models\Agenda;
use Validator;

class AgendaValidator
{

    /**
     * Determine if the given agenda is valid for complete status.
     *
     * @param Agenda $agenda
     *
     * @return bool / Validator
     */
    public function complete(Agenda $agenda)
    {
        return Validator::make($agenda->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given agenda is valid for verify status.
     *
     * @param Agenda $agenda
     *
     * @return bool / Validator
     */
    public function verify(Agenda $agenda)
    {
        return Validator::make($agenda->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given agenda is valid for approve status.
     *
     * @param Agenda $agenda
     *
     * @return bool / Validator
     */
    public function approve(Agenda $agenda)
    {
        return Validator::make($agenda->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given agenda is valid for publish status.
     *
     * @param Agenda $agenda
     *
     * @return bool / Validator
     */
    public function publish(Agenda $agenda)
    {
        return Validator::make($agenda->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given agenda is valid for archive status.
     *
     * @param Agenda $agenda
     *
     * @return bool / Validator
     */
    public function archive(Agenda $agenda)
    {
        return Validator::make($agenda->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given agenda is valid for unpublish status.
     *
     * @param Agenda $agenda
     *
     * @return bool / Validator
     */
    public function unpublish(Agenda $agenda)
    {
        return Validator::make($agenda->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
