<?php

namespace Ionut\Biblio\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Ionut\Biblio\Models\Edituri;

class EdituriAction
{
    /**
     * Perform the complete action.
     *
     * @param Edituri $edituri
     *
     * @return Edituri
     */
    public function complete(Edituri $edituri)
    {
        try {
            $edituri->status = 'complete';
            return $edituri->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Edituri $edituri
     *
     * @return Edituri
     */public function verify(Edituri $edituri)
    {
        try {
            $edituri->status = 'verify';
            return $edituri->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Edituri $edituri
     *
     * @return Edituri
     */public function approve(Edituri $edituri)
    {
        try {
            $edituri->status = 'approve';
            return $edituri->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Edituri $edituri
     *
     * @return Edituri
     */public function publish(Edituri $edituri)
    {
        try {
            $edituri->status = 'publish';
            return $edituri->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Edituri $edituri
     *
     * @return Edituri
     */
    public function archive(Edituri $edituri)
    {
        try {
            $edituri->status = 'archive';
            return $edituri->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Edituri $edituri
     *
     * @return Edituri
     */
    public function unpublish(Edituri $edituri)
    {
        try {
            $edituri->status = 'unpublish';
            return $edituri->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
