<?php

namespace Ionut\Biblio\Workflow;

use Ionut\Biblio\Models\Edituri;
use Validator;

class EdituriValidator
{

    /**
     * Determine if the given edituri is valid for complete status.
     *
     * @param Edituri $edituri
     *
     * @return bool / Validator
     */
    public function complete(Edituri $edituri)
    {
        return Validator::make($edituri->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given edituri is valid for verify status.
     *
     * @param Edituri $edituri
     *
     * @return bool / Validator
     */
    public function verify(Edituri $edituri)
    {
        return Validator::make($edituri->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given edituri is valid for approve status.
     *
     * @param Edituri $edituri
     *
     * @return bool / Validator
     */
    public function approve(Edituri $edituri)
    {
        return Validator::make($edituri->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given edituri is valid for publish status.
     *
     * @param Edituri $edituri
     *
     * @return bool / Validator
     */
    public function publish(Edituri $edituri)
    {
        return Validator::make($edituri->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given edituri is valid for archive status.
     *
     * @param Edituri $edituri
     *
     * @return bool / Validator
     */
    public function archive(Edituri $edituri)
    {
        return Validator::make($edituri->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given edituri is valid for unpublish status.
     *
     * @param Edituri $edituri
     *
     * @return bool / Validator
     */
    public function unpublish(Edituri $edituri)
    {
        return Validator::make($edituri->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
